<?php
require_once 'scripts/config.php';
require_once 'scripts/admin_functions.php';

// Получение треков для каждой вкладки
$tracksOnModeration = getTracksByStatus('moderation');
$approvedTracks = getTracksByStatus('approved');
$changesRequestedTracks = getTracksByStatus('changes_requested');

// Обработка действий модерации
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $action = $_POST['action'];
    $trackId = $_POST['trackId'];
    $comment = isset($_POST['comment']) ? $_POST['comment'] : '';

    switch ($action) {
        case 'approve':
            approveTrack($trackId);
            break;
        case 'reject':
            rejectTrack($trackId, $comment);
            break;
        case 'request_changes':
            requestChanges($trackId, $comment);
            break;
    }
}
?>

<h2>Модерация треков</h2>

<ul class="nav nav-tabs" id="myTab" role="tablist">
    <li class="nav-item" role="presentation">
        <button class="nav-link active" id="moderation-tab" data-bs-toggle="tab" data-bs-target="#moderation" type="button" role="tab" aria-controls="moderation" aria-selected="true">На модерации</button>
    </li>
    <li class="nav-item" role="presentation">
        <button class="nav-link" id="approved-tab" data-bs-toggle="tab" data-bs-target="#approved" type="button" role="tab" aria-controls="approved" aria-selected="false">Одобрено</button>
    </li>
    <li class="nav-item" role="presentation">
        <button class="nav-link" id="changes-tab" data-bs-toggle="tab" data-bs-target="#changes" type="button" role="tab" aria-controls="changes" aria-selected="false">Требуется изменения</button>
    </li>
</ul>

<div class="tab-content" id="myTabContent">
    <div class="tab-pane fade show active" id="moderation" role="tabpanel" aria-labelledby="moderation-tab">
        <?php displayTracks($tracksOnModeration); ?>
    </div>
    <div class="tab-pane fade" id="approved" role="tabpanel" aria-labelledby="approved-tab">
        <?php displayTracks($approvedTracks); ?>
    </div>
    <div class="tab-pane fade" id="changes" role="tabpanel" aria-labelledby="changes-tab">
        <?php displayTracks($changesRequestedTracks); ?>
    </div>
</div>

<!-- Модальное окно для комментария -->
<div class="modal fade" id="commentModal" tabindex="-1" aria-hidden="true">
    <div class="modal-dialog">
        <div class="modal-content">
            <div class="modal-header">
                <h5 class="modal-title">Оставить комментарий</h5>
                <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
            </div>
            <div class="modal-body">
                <form id="commentForm">
                    <input type="hidden" id="modalTrackId" name="trackId">
                    <input type="hidden" id="modalAction" name="action">
                    <div class="mb-3">
                        <label for="comment" class="form-label">Комментарий</label>
                        <textarea class="form-control" id="comment" name="comment" required></textarea>
                    </div>
                    <button type="submit" class="btn btn-primary">Отправить</button>
                </form>
            </div>
        </div>
    </div>
</div>

<!-- Модальное окно для подробной информации о треке -->
<div class="modal fade" id="trackDetailsModal" tabindex="-1" aria-hidden="true">
    <div class="modal-dialog modal-lg">
        <div class="modal-content">
            <div class="modal-header">
                <h5 class="modal-title">Подробная информация о треке</h5>
                <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
            </div>
            <div class="modal-body" id="trackDetailsContent">
                <!-- Содержимое будет загружено динамически -->
            </div>
        </div>
    </div>
</div>

<?php
function displayTracks($tracks) {
    if (empty($tracks)) {
        echo "<p>Нет треков для отображения.</p>";
        return;
    }
    ?>
    <table class="table table-striped">
        <thead>
            <tr>
                <th>ID</th>
                <th>Название</th>
                <th>Артист</th>
                <th>Действия</th>
            </tr>
        </thead>
        <tbody>
            <?php foreach ($tracks as $track): ?>
                <tr>
                    <td><?php echo $track['id']; ?></td>
                    <td><?php echo htmlspecialchars($track['track_name']); ?></td>
                    <td><?php echo htmlspecialchars($track['artist_name']); ?></td>
                    <td>
                        <button class="btn btn-sm btn-info play-track" data-track-path="<?php echo htmlspecialchars($track['file_path']); ?>">Прослушать</button>
                        <button class="btn btn-sm btn-primary view-details" data-track-id="<?php echo $track['id']; ?>">Подробнее</button>
                        <?php if ($track['status'] === 'moderation'): ?>
                            <button class="btn btn-sm btn-success approve-track" data-track-id="<?php echo $track['id']; ?>">Одобрить</button>
                            <button class="btn btn-sm btn-warning request-changes" data-track-id="<?php echo $track['id']; ?>">Запросить изменения</button>
                            <button class="btn btn-sm btn-danger reject-track" data-track-id="<?php echo $track['id']; ?>">Отклонить</button>
                        <?php endif; ?>
                    </td>
                </tr>
            <?php endforeach; ?>
        </tbody>
    </table>
    <?php
}
?>

<script>
$(document).ready(function() {
  
  $('.approve-track').click(function() {
    const trackId = $(this).data('track-id');
    if (confirm('Вы уверены, что хотите одобрить этот трек?')) {
        $.ajax({
            url: 'scripts/admin_actions.php?action=approve_track',
            type: 'POST',
            data: {trackId: trackId},
            dataType: 'json',
            success: function(response) {
                console.log('Server response:', response); // Для отладки
                if (response && response.status === 'success') {
                    alert(response.message || 'Трек успешно одобрен');
                    location.reload();
                } else {
                    alert('Ошибка: ' + (response && response.message ? response.message : 'Неизвестная ошибка'));
                }
            },
            error: function(jqXHR, textStatus, errorThrown) {
                console.error('AJAX error:', textStatus, errorThrown);
                alert('Ошибка при выполнении запроса: ' + textStatus);
            }
        });
    }
});
    $('.request-changes').click(function() {
        const trackId = $(this).data('track-id');
        $('#modalTrackId').val(trackId);
        $('#modalAction').val('request_changes');
        $('#commentModal').modal('show');
    });

    $('#commentForm').submit(function(e) {
        e.preventDefault();
        $.ajax({
            url: 'scripts/admin_actions.php?action=' + $('#modalAction').val(),
            type: 'POST',
            data: $(this).serialize(),
            dataType: 'json',
            success: function(response) {
                if (response.status === 'success') {
                    alert(response.message);
                    $('#commentModal').modal('hide');
                    location.reload();
                } else {
                    alert('Ошибка: ' + (response.message || 'Неизвестная ошибка'));
                }
            },
            error: function(jqXHR, textStatus, errorThrown) {
                console.error('AJAX error:', textStatus, errorThrown);
                alert('Ошибка при выполнении запроса: ' + textStatus);
            }
        });
    });

    $('.play-track').click(function() {
        const audioSrc = $(this).data('track-path');
        const audio = new Audio(audioSrc);
        audio.play();
    });

    $('.view-details').click(function() {
        const trackId = $(this).data('track-id');
        $.get('scripts/admin_actions.php?action=get_track_details', {trackId: trackId}, function(response) {
            if (response.status === 'success') {
                $('#trackDetailsContent').html(response.html);
                $('#trackDetailsModal').modal('show');
            } else {
                alert('Ошибка: ' + response.message);
            }
        });
    });
});
</script>
