<?php
// Файл: scripts/admin_actions.php
set_error_handler(function($errno, $errstr, $errfile, $errline) {
    error_log("Error: [$errno] $errstr in $errfile on line $errline");
    header('Content-Type: application/json');
    echo json_encode(['status' => 'error', 'message' => 'Произошла внутренняя ошибка сервера']);
    exit;
});

require_once 'config.php';
require_once 'admin_functions.php';

if (isset($_GET['action'])) {
    switch ($_GET['action']) {
      case 'approve_track':
          $trackId = $_POST['trackId'];
          error_log("Approving track - Track ID: $trackId");
          $result = approveTrack($trackId);
          error_log("Approve track result: " . json_encode($result));
          header('Content-Type: application/json');
          echo json_encode($result);
          exit;

        case 'reject_track':
            $trackId = $_POST['trackId'];
            $comment = $_POST['comment'];
            $result = rejectTrack($trackId, $comment);
            echo json_encode(['status' => $result ? 'success' : 'error']);
            break;

        case 'request_changes':
            $trackId = $_POST['trackId'];
            $comment = $_POST['comment'];
            $result = requestChanges($trackId, $comment);
            echo json_encode($result);
            break;

        case 'send_to_moderation':
            $trackId = $_POST['trackId'];
            $stmt = $mysqli->prepare("UPDATE tracks SET status = 'moderation' WHERE id = ? AND user_id = ?");
            $stmt->bind_param("ii", $trackId, $user_id);
            if ($stmt->execute()) {
                echo json_encode(['status' => 'success', 'message' => 'Трек отправлен на модерацию']);
            } else {
                echo json_encode(['status' => 'error', 'message' => 'Ошибка при отправке трека на модерацию']);
            }
            break;

        case 'get_track_details':
            $trackId = $_GET['trackId'];
            $track = getTrackDetails($trackId);
            if ($track) {
                $html = "<h3>{$track['track_name']}</h3>";
                $html .= "<p><strong>Артист:</strong> {$track['artist_name']}</p>";
                $html .= "<p><strong>Статус:</strong> {$track['status']}</p>";
                $html .= "<p><strong>Автор музыки:</strong> {$track['music_author']}</p>";
                $html .= "<p><strong>Автор текста:</strong> {$track['lyrics_author']}</p>";
                $html .= "<p><strong>Текст песни:</strong><br>" . nl2br($track['lyrics']) . "</p>";
                $html .= "<p><strong>Дата создания:</strong> {$track['created_at']}</p>";
                $html .= "<p><strong>Комментарий модератора:</strong> {$track['moderation_comment']}</p>";
                $html .= "<audio controls><source src='{$track['file_path']}' type='audio/mpeg'>Ваш браузер не поддерживает аудио элемент.</audio>";
                echo json_encode(['status' => 'success', 'html' => $html]);
            } else {
                echo json_encode(['status' => 'error', 'message' => 'Трек не найден']);
            }
            break;
    }
}
restore_error_handler();
